==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/kn.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "﻿ಲಭ್ಯವಿಲ್ಲ ಸಂಗ್ರಹ",
    "Storage invalid" : "ಸಂಗ್ರಹ ಅಮಾನ್ಯವಾಗಿದೆ",
    "Unknown error" : "ಗೊತ್ತಿಲ್ಲದ ದೋಷ",
    "Could not move %s - File with this name already exists" : "﻿%s ಹೆಸರು ಈಗಾಗಲೇ ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ  - ಸ್ಥಳ ಬದಲಾವಣೆ ಸಾಧ್ಯವಿಲ್ಲ",
    "Could not move %s" : "%s ಸ್ಥಳ ಬದಲಾವಣೆ ಸಾಧ್ಯವಿಲ್ಲ",
    "Permission denied" : "ಅನುಮತಿ ನಿರಾಕರಿಸಲಾಗಿದೆ",
    "The target folder has been moved or deleted." : "ಕೋಶದ ಉದ್ದೇಶಿತ ಸ್ಥಳ ಬದಲಾವಣೆ ಮಾಡಲಾಗಿದೆ ಅಥವಾ ಅಳಿಸಲಾಗಿದೆ.",
    "The name %s is already used in the folder %s. Please choose a different name." : "%s ಹೆಸರಿನ ಕೋಶವನ್ನು %s ಈಗಾಗಲೇ ಬಳಸಲಾಗುತ್ತದೆ.  ಬೇರೆ ಹೆಸರನ್ನು ಆಯ್ಕೆಮಾಡಿ.",
    "Error when creating the file" : "ಕಡತವನ್ನು ರಚಿಸುವಾಗ ದೋಷವಾಗಿದೆ",
    "Error when creating the folder" : "ಕೊಶವನ್ನು ರಚಿಸುವಾಗ ದೋಷವಾಗಿದೆ",
    "Unable to set upload directory." : "ಪೇರಿಸವ ಕೋಶವನ್ನು ಹೊಂದಿಸಲಾಗಲಿಲ್ಲ.",
    "Invalid Token" : "﻿ಅಮಾನ್ಯ ಸಾಂಕೇತಿಕ",
    "No file was uploaded. Unknown error" : "ಕಡತ ವರ್ಗಾವಣೆ ಅಜ್ಞಾತ ದೋಷದಿಂದ ವಿಪುಲವಾಗಿದೆ",
    "There is no error, the file uploaded with success" : "ವರ್ಗಾವಣೆ ﻿ಯಾವುದೇ ದೋಷ ಕಂಡುಬರದೆ ಯಶಸ್ವಿಯಾಗಿದೆ",
    "The uploaded file was only partially uploaded" : "ವರ್ಗಾವಣೆ ಮಾಡಲಾಗುತ್ತಿದ್ದ ಕಡತವನ್ನು ಭಾಗಶಃ ಮಾತ್ರ ಪೇರಿಸಲು ಸಾದ್ಯವಾಗಿದೆ",
    "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
    "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
    "Failed to write to disk" : "ಸ್ಮರಣೆ ಸಾಧನಕ್ಕೇಬರೆಯಲು ವಿಫಲವಾಗಿದೆ",
    "Not enough storage available" : "﻿ಲಭ್ಯವಿರುವ ಸಂಗ್ರಹ ಸಾಕಾಗುವುದಿಲ್ಲ",
    "Invalid directory." : "﻿ಅಮಾನ್ಯ ಕಡತಕೋಶ.",
    "Files" : "﻿ಕಡತಗಳು",
    "All files" : "﻿ಎಲ್ಲಾ ಕಡತಗಳು",
    "Favorites" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Home" : "﻿ಮುಖಪುಟ",
    "Close" : "ಮುಚ್ಚು",
    "Upload cancelled." : "ವರ್ಗಾವಣೆಯನ್ನು ರದ್ದು ಮಾಡಲಾಯಿತು.",
    "Could not get result from server." : "﻿ಪರಿಚಾರಕ ಕಣಕದಿಂದ ಫಲಿತಾಂಶವನ್ನು ಪಡೆಯಲು ಸಾಧ್ಯವಾಗಿಲ್ಲ.",
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Rename" : "﻿ಮರುಹೆಸರಿಸು",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Select" : "ಆಯ್ಕೆ ಮಾಡಿ",
    "Pending" : "﻿ಬಾಕಿ ಇದೆ",
    "Unable to determine date" : "﻿ಮುಕ್ತಾಯ ದಿನಾಂಕ ನಿರ್ಧರಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Error moving file." : "ಕಡತದ ಸ್ಥಾನವನ್ನು ಬದಲಾಯಿಸುವಾಗ ದೋಷವಾಗಿದೆ.",
    "Error moving file" : "ಕಡತದ ಸ್ಥಾನವನ್ನು ಬದಲಾಯಿಸುವಾಗ ದೋಷವಾಗಿದೆ",
    "Error" : "﻿ತಪ್ಪಾಗಿದೆ",
    "{new_name} already exists" : "ಈಗಾಗಲೇ {new_name}  ಅಸ್ತಿತ್ವದಲ್ಲಿದೆ",
    "Could not rename file" : "﻿ಕಡತ ಮರುಹೆಸರಿಸಲು ಸಾಧ್ಯವಾಗಲಿಲ್ಲ",
    "Could not create file" : "﻿ಕಡತ ರಚಿಸಲಾಗಲಿಲ್ಲ",
    "Could not create folder" : "ಕೋಶವನ್ನು ರಚಿಸಲಾಗಿಲ್ಲ",
    "Error deleting file." : "ಕಡತವನ್ನು ಅಳಿಸುವಲ್ಲಿ ಲೋಪವಾದೆ",
    "Name" : "﻿ಹೆಸರು",
    "Size" : "﻿ ಪ್ರಮಾಣ",
    "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
    "_%n folder_::_%n folders_" : ["%n ಕೋಶ(ಗಳು)"],
    "_%n file_::_%n files_" : ["%n ಕಡತ"],
    "You don’t have permission to upload or create files here" : "﻿ನಿಮಗೆ ಇಲ್ಲಿ ಅಪ್ಲೋಡ್ ಅಥವಾ ಕಡತಗಳನ್ನು ರಚಿಸವ ಅನುಮತಿ ಇಲ್ಲ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 'ನೆ ಕಡತವನ್ನು ವರ್ಗಾಯಿಸಲಾಗುತ್ತಿದೆ"],
    "New" : "﻿ಹೊಸ",
    "File name cannot be empty." : "ಕಡತ ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.",
    "Favorited" : "ಅಚ್ಚುಮೆಚ್ಚಿನವು",
    "Favorite" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Upload" : "ವರ್ಗಾಯಿಸಿ",
    "Text file" : "ಸರಳಾಕ್ಷರದ ಕಡತ",
    "Folder" : "ಕಡತಕೋಶ",
    "New folder" : "ಹೊಸ ಕಡತಕೋಶ",
    "Upload (max. %s)" : "ವರ್ಗಾವಣೆ (ಗರಿಷ್ಠ %s)",
    "File handling" : "﻿ಕಡತ ನಿರ್ವಹಣೆ",
    "Maximum upload size" : "ಗರಿಷ್ಠ ವರ್ಗಾವಣೆ ಗಾತ್ರ",
    "max. possible: " : "﻿ಗರಿಷ್ಠ. ಸಾಧ್ಯ:",
    "Save" : "﻿ಉಳಿಸಿ",
    "Settings" : "ಆಯ್ಕೆ",
    "WebDAV" : "﻿WebDAV",
    "Cancel upload" : "﻿ವರ್ಗಾವಣೆ ರದ್ದು ಮಾಡಿ",
    "Select all" : "﻿ಎಲ್ಲಾ ಆಯ್ಕೆ ಮಾಡಿ",
    "Upload too large" : "ದೊಡ್ಡ ಪ್ರಮಾಣದ ಪ್ರತಿಗಳನ್ನು ವರ್ಗಾವಣೆ ಮಾಡಲು ಸಾದ್ಯವಿಲ್ಲ",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ನೀವು ವರ್ಗಾಯಿಸಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಕಡತಗಳ ಗಾತ್ರ, ಈ ಗಣಕ ಕೋಶದ ಗರಿಷ್ಠ ಕಡತ ಮೀತಿಯಾನ್ನು ಮೀರುವಂತಿಲ್ಲ.",
    "Files are being scanned, please wait." : "﻿ಕಡತಗಳನ್ನು ಪರೀಕ್ಷಿಸಲಾಗುತ್ತಿದೆ, ದಯವಿಟ್ಟು ನಿರೀಕ್ಷಿಸಿ.",
    "Currently scanning" : "﻿ಪ್ರಸ್ತುತ ಪರೀಕ್ಷೆ",
    "No favorites" : "ಯಾವ ಅಚ್ಚುಮೆಚ್ಚಿನವುಗಳು ಇಲ್ಲ",
    "Files and folders you mark as favorite will show up here" : "ನೀವು ಗುರುತು ಮಾಡಿರುವ ನೆಚ್ಚಿನ ಕಡತ ಮತ್ತು ಕಡತಕೋಶಗಳನ್ನು ಇಲ್ಲಿ ತೋರಿಸಲಾಗುತ್ತಿದೆ",
    "Upload cancelled." : "ವರ್ಗಾವಣೆಯನ್ನು ರದ್ದು ಮಾಡಲಾಯಿತು."
},
"nplurals=1; plural=0;");

==> owncloud-9.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/kn.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "﻿ಲಭ್ಯವಿಲ್ಲ ಸಂಗ್ರಹ",
    "Storage invalid" : "ಸಂಗ್ರಹ ಅಮಾನ್ಯವಾಗಿದೆ",
    "Unknown error" : "ಗೊತ್ತಿಲ್ಲದ ದೋಷ",
    "Unable to set upload directory." : "ಪೇರಿಸವ ಕೋಶವನ್ನು ಹೊಂದಿಸಲಾಗಲಿಲ್ಲ.",
    "Invalid Token" : "﻿ಅಮಾನ್ಯ ಸಾಂಕೇತಿಕ",
    "No file was uploaded. Unknown error" : "ಕಡತ ವರ್ಗಾವಣೆ ಅಜ್ಞಾತ ದೋಷದಿಂದ ವಿಪುಲವಾಗಿದೆ",
    "There is no error, the file uploaded with success" : "ವರ್ಗಾವಣೆ ﻿ಯಾವುದೇ ದೋಷ ಕಂಡುಬರದೆ ಯಶಸ್ವಿಯಾಗಿದೆ",
    "The uploaded file was only partially uploaded" : "ವರ್ಗಾವಣೆ ಮಾಡಲಾಗುತ್ತಿದ್ದ ಕಡತವನ್ನು ಭಾಗಶಃ ಮಾತ್ರ ಪೇರಿಸಲು ಸಾದ್ಯವಾಗಿದೆ",
    "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
    "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
    "Failed to write to disk" : "ಸ್ಮರಣೆ ಸಾಧನಕ್ಕೇಬರೆಯಲು ವಿಫಲವಾಗಿದೆ",
    "Not enough storage available" : "﻿ಲಭ್ಯವಿರುವ ಸಂಗ್ರಹ ಸಾಕಾಗುವುದಿಲ್ಲ",
    "The target folder has been moved or deleted." : "ಕೋಶದ ಉದ್ದೇಶಿತ ಸ್ಥಳ ಬದಲಾವಣೆ ಮಾಡಲಾಗಿದೆ ಅಥವಾ ಅಳಿಸಲಾಗಿದೆ.",
    "Invalid directory." : "﻿ಅಮಾನ್ಯ ಕಡತಕೋಶ.",
    "Files" : "﻿ಕಡತಗಳು",
    "All files" : "﻿ಎಲ್ಲಾ ಕಡತಗಳು",
    "Favorites" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Home" : "﻿ಮುಖಪುಟ",
    "Close" : "ಮುಚ್ಚು",
    "Upload cancelled." : "ವರ್ಗಾವಣೆಯನ್ನು ರದ್ದು ಮಾಡಲಾಯಿತು.",
    "Could not get result from server." : "﻿ಪರಿಚಾರಕ ಕಣಕದಿಂದ ಫಲಿತಾಂಶವನ್ನು ಪಡೆಯಲು ಸಾಧ್ಯವಾಗಿಲ್ಲ.",
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Rename" : "﻿ಮರುಹೆಸರಿಸು",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Disconnect storage" : "ಸಂಗ್ರಹ ಸಾಧನವನ್ನು ತೆಗೆದುಹಾಕಿ",
    "Unshare" : "ಹಂಚಿಕೆಯನ್ನು ಹಿಂತೆಗೆ",
    "Select" : "ಆಯ್ಕೆ ಮಾಡಿ",
    "Pending" : "﻿ಬಾಕಿ ಇದೆ",
    "Unable to determine date" : "﻿ಮುಕ್ತಾಯ ದಿನಾಂಕ ನಿರ್ಧರಿಸಲು ಸಾಧ್ಯವಿಲ್ಲ",
    "Name" : "﻿ಹೆಸರು",
    "Size" : "﻿ ಪ್ರಮಾಣ",
    "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
    "_%n folder_::_%n folders_" : ["%n ಕೋಶ(ಗಳು)"],
    "_%n file_::_%n files_" : ["%n ಕಡತ"],
    "You don’t have permission to upload or create files here" : "﻿ನಿಮಗೆ ಇಲ್ಲಿ ಅಪ್ಲೋಡ್ ಅಥವಾ ಕಡತಗಳನ್ನು ರಚಿಸವ ಅನುಮತಿ ಇಲ್ಲ",
    "_Uploading %n file_::_Uploading %n files_" : ["%n 'ನೆ ಕಡತವನ್ನು ವರ್ಗಾಯಿಸಲಾಗುತ್ತಿದೆ"],
    "New" : "﻿ಹೊಸ",
    "File name cannot be empty." : "ಕಡತ ಹೆಸರು ಖಾಲಿ ಇರುವಂತಿಲ್ಲ.",
    "Favorited" : "ಅಚ್ಚುಮೆಚ್ಚಿನವು",
    "Favorite" : "ಅಚ್ಚುಮೆಚ್ಚಿನ",
    "Folder" : "ಕಡತಕೋಶ",
    "New folder" : "ಹೊಸ ಕಡತಕೋಶ",
    "Upload" : "ವರ್ಗಾಯಿಸಿ",
    "Upload (max. %s)" : "ವರ್ಗಾವಣೆ (ಗರಿಷ್ಠ %s)",
    "File handling" : "﻿ಕಡತ ನಿರ್ವಹಣೆ",
    "Maximum upload size" : "ಗರಿಷ್ಠ ವರ್ಗಾವಣೆ ಗಾತ್ರ",
    "max. possible: " : "﻿ಗರಿಷ್ಠ. ಸಾಧ್ಯ:",
    "Save" : "﻿ಉಳಿಸಿ",
    "Settings" : "ಆಯ್ಕೆ",
    "WebDAV" : "﻿WebDAV",
    "Cancel upload" : "﻿ವರ್ಗಾವಣೆ ರದ್ದು ಮಾಡಿ",
    "Select all" : "﻿ಎಲ್ಲಾ ಆಯ್ಕೆ ಮಾಡಿ",
    "Upload too large" : "ದೊಡ್ಡ ಪ್ರಮಾಣದ ಪ್ರತಿಗಳನ್ನು ವರ್ಗಾವಣೆ ಮಾಡಲು ಸಾದ್ಯವಿಲ್ಲ",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "ನೀವು ವರ್ಗಾಯಿಸಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಕಡತಗಳ ಗಾತ್ರ, ಈ ಗಣಕ ಕೋಶದ ಗರಿಷ್ಠ ಕಡತ ಮೀತಿಯಾನ್ನು ಮೀರುವಂತಿಲ್ಲ.",
    "No favorites" : "ಯಾವ ಅಚ್ಚುಮೆಚ್ಚಿನವುಗಳು ಇಲ್ಲ",
    "Files and folders you mark as favorite will show up here" : "ನೀವು ಗುರುತು ಮಾಡಿರುವ ನೆಚ್ಚಿನ ಕಡತ ಮತ್ತು ಕಡತಕೋಶಗಳನ್ನು ಇಲ್ಲಿ ತೋರಿಸಲಾಗುತ್ತಿದೆ",
    "Text file" : "ಸರಳಾಕ್ಷರದ ಕಡತ"
},
"nplurals=1; plural=0;");
